EXPERIMENT_PATH = "experiment-path"
EXPERIMENT_LABELS = "experiment-labels"
PROBE_DIAMETER = "probe-diameter"
LOAD_EXPERIMENT = "load-experiment"
LOAD_OUTPUT = "load-output"
EXPERIMENT = "experiment"
IMAGES = "images"

CURVE_DROPDOWN = "curve-dropdown"
CURVE_DATA = "curve-data"
LOAD_ANIMATION = "load-animation"
BUTTON_BACK = "button-back"
BUTTON_FORWARD = "button-forward"

IMAGE_FRAME = "image-frame"
LOADIMAGE_ANIMATION = "loadimage-animation"

UPLOAD_ANNOTATIONS = "upload-annotations"
CP_ANNOTATIONS = "cp-annotations"
VD_ANNOTATIONS = "vd-annotations"

VD_CHECKLIST = "vd-checklist"
ADJUST_CHECKLIST = "adjust-checklist"
LOADCONTACT_ANIMATION = "loadcontact-animation"
DETECT_CONTACT = "detect-contact"
RESET_CONTACT = "reset-contact"
FIT_CHECKLIST = "fit-checklist"
INDENTATION = "indentation"

DOWNLOAD_ANNOTATIONS = "download-annotations"
DOWNLOAD_IMAGEDATA = "download-imagedata"
DOWNLOAD_FITS = "download-fits"
DOWNLOAD_CURVES = "download-curves"
DOWNLOAD_EXPERIMENT = "download-experiment"
DOWNLOAD_ANIMATION = "download-animation"
DOWNLOAD = 'download'

FIG_HOLDER = "fig-holder"
CONTACT_FIG = "contact-fig"
FORCETIME_FIG = "forcetime-fig"
