hr {
    border-top: 2px solid gray;
    margin: 12px auto;
}

.dropdown-container {
    display: grid;
    grid-template-columns: repeat(3, 1fr);
    gap: 10px;
}

.dropdown-button {
    width: 100%;
    margin-top: 5px;
}

.tabs-group {
    padding-top: 20px;
}

.app-div {
    padding: 10px;
}

.data-table-div {
    margin: auto;
    padding: 10px;
}

.budget-label {
    font-size: 20px;
    font-weight: bold;
}

.budget-text {
    font-size: 20px;
}

.budget-text-value {
    font-size: 20px;
    font-style: italic;
}

.budget-progress-bar {
    height: 20px;
}

.budget-tooltip {
    font-size: 18px;
}

.checklist {
    text-align: center;
    padding-top: 10px;
    padding-bottom: 20px;
}

.dash-input {
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    border-radius: 5px;
    border-width: 1px;
}

.drag-drop {
    width: 100%;
    height: 33px;
    line-height: 28px;
    border-width: 1px;
    border-style: dashed;
    border-radius: 5px;
    text-align: center;
    margin: 2px;
}

.dash-button {
    border-radius: 5px;
    border-width: 1px;
}

.dash-graph {
    height: 400px;
}



@media(max-width: 800px) {
    .dropdown-container {
        grid-template-columns: 1fr;
    }
}